@@ -13,10 +13,23 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_comprehend.literals import (
+    DocumentClassifierDataFormat,
+    DocumentClassifierMode,
+    EndpointStatus,
+    EntityRecognizerDataFormat,
+    EntityType,
+    InputFormat,
+    JobStatus,
+    LanguageCode,
+    ModelStatus,
+    PartOfSpeechTagType,
+    PiiEntitiesDetectionMaskMode,
+    PiiEntitiesDetectionMode,
+    PiiEntityType,
+    SentimentType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -162,11 +175,7 @@ BatchDetectKeyPhrasesItemResultTypeDef = TypedDict(
 
 BatchDetectSentimentItemResultTypeDef = TypedDict(
     "BatchDetectSentimentItemResultTypeDef",
-    {
-        "Index": int,
-        "Sentiment": Literal["POSITIVE", "NEGATIVE", "NEUTRAL", "MIXED"],
-        "SentimentScore": "SentimentScoreTypeDef",
-    },
+    {"Index": int, "Sentiment": SentimentType, "SentimentScore": "SentimentScoreTypeDef"},
     total=False,
 )
 
@@ -213,9 +222,7 @@ DocumentClassificationJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
@@ -232,7 +239,7 @@ DocumentClassificationJobPropertiesTypeDef = TypedDict(
 DocumentClassifierInputDataConfigTypeDef = TypedDict(
     "DocumentClassifierInputDataConfigTypeDef",
     {
-        "DataFormat": Literal["COMPREHEND_CSV", "AUGMENTED_MANIFEST"],
+        "DataFormat": DocumentClassifierDataFormat,
         "S3Uri": str,
         "LabelDelimiter": str,
         "AugmentedManifests": List["AugmentedManifestsListItemTypeDef"],
@@ -248,12 +255,8 @@ DocumentClassifierPropertiesTypeDef = TypedDict(
     "DocumentClassifierPropertiesTypeDef",
     {
         "DocumentClassifierArn": str,
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
-        "Status": Literal[
-            "SUBMITTED", "TRAINING", "DELETING", "STOP_REQUESTED", "STOPPED", "IN_ERROR", "TRAINED"
-        ],
+        "LanguageCode": LanguageCode,
+        "Status": ModelStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
@@ -265,7 +268,7 @@ DocumentClassifierPropertiesTypeDef = TypedDict(
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Mode": Literal["MULTI_CLASS", "MULTI_LABEL"],
+        "Mode": DocumentClassifierMode,
         "ModelKmsKeyId": str,
     },
     total=False,
@@ -278,9 +281,7 @@ DominantLanguageDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
@@ -301,7 +302,7 @@ EndpointPropertiesTypeDef = TypedDict(
     "EndpointPropertiesTypeDef",
     {
         "EndpointArn": str,
-        "Status": Literal["CREATING", "DELETING", "FAILED", "IN_SERVICE", "UPDATING"],
+        "Status": EndpointStatus,
         "Message": str,
         "ModelArn": str,
         "DesiredInferenceUnits": int,
@@ -318,18 +319,14 @@ EntitiesDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "EntityRecognizerArn": str,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
@@ -338,36 +335,7 @@ EntitiesDetectionJobPropertiesTypeDef = TypedDict(
 )
 
 EntityLabelTypeDef = TypedDict(
-    "EntityLabelTypeDef",
-    {
-        "Name": Literal[
-            "BANK_ACCOUNT_NUMBER",
-            "BANK_ROUTING",
-            "CREDIT_DEBIT_NUMBER",
-            "CREDIT_DEBIT_CVV",
-            "CREDIT_DEBIT_EXPIRY",
-            "PIN",
-            "EMAIL",
-            "ADDRESS",
-            "NAME",
-            "PHONE",
-            "SSN",
-            "DATE_TIME",
-            "PASSPORT_NUMBER",
-            "DRIVER_ID",
-            "URL",
-            "AGE",
-            "USERNAME",
-            "PASSWORD",
-            "AWS_ACCESS_KEY",
-            "AWS_SECRET_KEY",
-            "IP_ADDRESS",
-            "MAC_ADDRESS",
-            "ALL",
-        ],
-        "Score": float,
-    },
-    total=False,
+    "EntityLabelTypeDef", {"Name": PiiEntityType, "Score": float}, total=False
 )
 
 EntityRecognizerAnnotationsTypeDef = TypedDict("EntityRecognizerAnnotationsTypeDef", {"S3Uri": str})
@@ -389,7 +357,7 @@ _RequiredEntityRecognizerInputDataConfigTypeDef = TypedDict(
 _OptionalEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_OptionalEntityRecognizerInputDataConfigTypeDef",
     {
-        "DataFormat": Literal["COMPREHEND_CSV", "AUGMENTED_MANIFEST"],
+        "DataFormat": EntityRecognizerDataFormat,
         "Documents": "EntityRecognizerDocumentsTypeDef",
         "Annotations": "EntityRecognizerAnnotationsTypeDef",
         "EntityList": "EntityRecognizerEntityListTypeDef",
@@ -430,12 +398,8 @@ EntityRecognizerPropertiesTypeDef = TypedDict(
     "EntityRecognizerPropertiesTypeDef",
     {
         "EntityRecognizerArn": str,
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
-        "Status": Literal[
-            "SUBMITTED", "TRAINING", "DELETING", "STOP_REQUESTED", "STOPPED", "IN_ERROR", "TRAINED"
-        ],
+        "LanguageCode": LanguageCode,
+        "Status": ModelStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
@@ -453,23 +417,7 @@ EntityRecognizerPropertiesTypeDef = TypedDict(
 
 EntityTypeDef = TypedDict(
     "EntityTypeDef",
-    {
-        "Score": float,
-        "Type": Literal[
-            "PERSON",
-            "LOCATION",
-            "ORGANIZATION",
-            "COMMERCIAL_ITEM",
-            "EVENT",
-            "DATE",
-            "QUANTITY",
-            "TITLE",
-            "OTHER",
-        ],
-        "Text": str,
-        "BeginOffset": int,
-        "EndOffset": int,
-    },
+    {"Score": float, "Type": EntityType, "Text": str, "BeginOffset": int, "EndOffset": int},
     total=False,
 )
 
@@ -486,17 +434,13 @@ EventsDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
         "TargetEventTypes": List[str],
     },
@@ -505,9 +449,7 @@ EventsDetectionJobPropertiesTypeDef = TypedDict(
 
 _RequiredInputDataConfigTypeDef = TypedDict("_RequiredInputDataConfigTypeDef", {"S3Uri": str})
 _OptionalInputDataConfigTypeDef = TypedDict(
-    "_OptionalInputDataConfigTypeDef",
-    {"InputFormat": Literal["ONE_DOC_PER_FILE", "ONE_DOC_PER_LINE"]},
-    total=False,
+    "_OptionalInputDataConfigTypeDef", {"InputFormat": InputFormat}, total=False
 )
 
 
@@ -526,17 +468,13 @@ KeyPhrasesDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
@@ -555,31 +493,7 @@ class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputD
 
 
 PartOfSpeechTagTypeDef = TypedDict(
-    "PartOfSpeechTagTypeDef",
-    {
-        "Tag": Literal[
-            "ADJ",
-            "ADP",
-            "ADV",
-            "AUX",
-            "CONJ",
-            "CCONJ",
-            "DET",
-            "INTJ",
-            "NOUN",
-            "NUM",
-            "O",
-            "PART",
-            "PRON",
-            "PROPN",
-            "PUNCT",
-            "SCONJ",
-            "SYM",
-            "VERB",
-        ],
-        "Score": float,
-    },
-    total=False,
+    "PartOfSpeechTagTypeDef", {"Tag": PartOfSpeechTagType, "Score": float}, total=False
 )
 
 PiiEntitiesDetectionJobPropertiesTypeDef = TypedDict(
@@ -587,56 +501,23 @@ PiiEntitiesDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "PiiOutputDataConfigTypeDef",
         "RedactionConfig": "RedactionConfigTypeDef",
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
-        "Mode": Literal["ONLY_REDACTION", "ONLY_OFFSETS"],
+        "Mode": PiiEntitiesDetectionMode,
     },
     total=False,
 )
 
 PiiEntityTypeDef = TypedDict(
     "PiiEntityTypeDef",
-    {
-        "Score": float,
-        "Type": Literal[
-            "BANK_ACCOUNT_NUMBER",
-            "BANK_ROUTING",
-            "CREDIT_DEBIT_NUMBER",
-            "CREDIT_DEBIT_CVV",
-            "CREDIT_DEBIT_EXPIRY",
-            "PIN",
-            "EMAIL",
-            "ADDRESS",
-            "NAME",
-            "PHONE",
-            "SSN",
-            "DATE_TIME",
-            "PASSPORT_NUMBER",
-            "DRIVER_ID",
-            "URL",
-            "AGE",
-            "USERNAME",
-            "PASSWORD",
-            "AWS_ACCESS_KEY",
-            "AWS_SECRET_KEY",
-            "IP_ADDRESS",
-            "MAC_ADDRESS",
-            "ALL",
-        ],
-        "BeginOffset": int,
-        "EndOffset": int,
-    },
+    {"Score": float, "Type": PiiEntityType, "BeginOffset": int, "EndOffset": int},
     total=False,
 )
 
@@ -657,34 +538,8 @@ class PiiOutputDataConfigTypeDef(
 RedactionConfigTypeDef = TypedDict(
     "RedactionConfigTypeDef",
     {
-        "PiiEntityTypes": List[
-            Literal[
-                "BANK_ACCOUNT_NUMBER",
-                "BANK_ROUTING",
-                "CREDIT_DEBIT_NUMBER",
-                "CREDIT_DEBIT_CVV",
-                "CREDIT_DEBIT_EXPIRY",
-                "PIN",
-                "EMAIL",
-                "ADDRESS",
-                "NAME",
-                "PHONE",
-                "SSN",
-                "DATE_TIME",
-                "PASSPORT_NUMBER",
-                "DRIVER_ID",
-                "URL",
-                "AGE",
-                "USERNAME",
-                "PASSWORD",
-                "AWS_ACCESS_KEY",
-                "AWS_SECRET_KEY",
-                "IP_ADDRESS",
-                "MAC_ADDRESS",
-                "ALL",
-            ]
-        ],
-        "MaskMode": Literal["MASK", "REPLACE_WITH_PII_ENTITY_TYPE"],
+        "PiiEntityTypes": List[PiiEntityType],
+        "MaskMode": PiiEntitiesDetectionMaskMode,
         "MaskCharacter": str,
     },
     total=False,
@@ -695,17 +550,13 @@ SentimentDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
         "InputDataConfig": "InputDataConfigTypeDef",
         "OutputDataConfig": "OutputDataConfigTypeDef",
-        "LanguageCode": Literal[
-            "en", "es", "fr", "de", "it", "pt", "ar", "hi", "ja", "ko", "zh", "zh-TW"
-        ],
+        "LanguageCode": LanguageCode,
         "DataAccessRoleArn": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
@@ -744,9 +595,7 @@ TopicsDetectionJobPropertiesTypeDef = TypedDict(
     {
         "JobId": str,
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "Message": str,
         "SubmitTime": datetime,
         "EndTime": datetime,
@@ -912,10 +761,7 @@ DetectPiiEntitiesResponseTypeDef = TypedDict(
 
 DetectSentimentResponseTypeDef = TypedDict(
     "DetectSentimentResponseTypeDef",
-    {
-        "Sentiment": Literal["POSITIVE", "NEGATIVE", "NEUTRAL", "MIXED"],
-        "SentimentScore": "SentimentScoreTypeDef",
-    },
+    {"Sentiment": SentimentType, "SentimentScore": "SentimentScoreTypeDef"},
     total=False,
 )
 
@@ -927,9 +773,7 @@ DocumentClassificationJobFilterTypeDef = TypedDict(
     "DocumentClassificationJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -938,13 +782,7 @@ DocumentClassificationJobFilterTypeDef = TypedDict(
 
 DocumentClassifierFilterTypeDef = TypedDict(
     "DocumentClassifierFilterTypeDef",
-    {
-        "Status": Literal[
-            "SUBMITTED", "TRAINING", "DELETING", "STOP_REQUESTED", "STOPPED", "IN_ERROR", "TRAINED"
-        ],
-        "SubmitTimeBefore": datetime,
-        "SubmitTimeAfter": datetime,
-    },
+    {"Status": ModelStatus, "SubmitTimeBefore": datetime, "SubmitTimeAfter": datetime},
     total=False,
 )
 
@@ -952,9 +790,7 @@ DominantLanguageDetectionJobFilterTypeDef = TypedDict(
     "DominantLanguageDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -965,7 +801,7 @@ EndpointFilterTypeDef = TypedDict(
     "EndpointFilterTypeDef",
     {
         "ModelArn": str,
-        "Status": Literal["CREATING", "DELETING", "FAILED", "IN_SERVICE", "UPDATING"],
+        "Status": EndpointStatus,
         "CreationTimeBefore": datetime,
         "CreationTimeAfter": datetime,
     },
@@ -976,9 +812,7 @@ EntitiesDetectionJobFilterTypeDef = TypedDict(
     "EntitiesDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -987,13 +821,7 @@ EntitiesDetectionJobFilterTypeDef = TypedDict(
 
 EntityRecognizerFilterTypeDef = TypedDict(
     "EntityRecognizerFilterTypeDef",
-    {
-        "Status": Literal[
-            "SUBMITTED", "TRAINING", "DELETING", "STOP_REQUESTED", "STOPPED", "IN_ERROR", "TRAINED"
-        ],
-        "SubmitTimeBefore": datetime,
-        "SubmitTimeAfter": datetime,
-    },
+    {"Status": ModelStatus, "SubmitTimeBefore": datetime, "SubmitTimeAfter": datetime},
     total=False,
 )
 
@@ -1001,9 +829,7 @@ EventsDetectionJobFilterTypeDef = TypedDict(
     "EventsDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -1014,9 +840,7 @@ KeyPhrasesDetectionJobFilterTypeDef = TypedDict(
     "KeyPhrasesDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -1134,9 +958,7 @@ PiiEntitiesDetectionJobFilterTypeDef = TypedDict(
     "PiiEntitiesDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -1147,9 +969,7 @@ SentimentDetectionJobFilterTypeDef = TypedDict(
     "SentimentDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
@@ -1158,165 +978,77 @@ SentimentDetectionJobFilterTypeDef = TypedDict(
 
 StartDocumentClassificationJobResponseTypeDef = TypedDict(
     "StartDocumentClassificationJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StartDominantLanguageDetectionJobResponseTypeDef = TypedDict(
     "StartDominantLanguageDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StartEntitiesDetectionJobResponseTypeDef = TypedDict(
-    "StartEntitiesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StartEntitiesDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StartEventsDetectionJobResponseTypeDef = TypedDict(
-    "StartEventsDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StartEventsDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StartKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
     "StartKeyPhrasesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StartPiiEntitiesDetectionJobResponseTypeDef = TypedDict(
     "StartPiiEntitiesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StartSentimentDetectionJobResponseTypeDef = TypedDict(
-    "StartSentimentDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StartSentimentDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StartTopicsDetectionJobResponseTypeDef = TypedDict(
-    "StartTopicsDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StartTopicsDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StopDominantLanguageDetectionJobResponseTypeDef = TypedDict(
     "StopDominantLanguageDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StopEntitiesDetectionJobResponseTypeDef = TypedDict(
-    "StopEntitiesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StopEntitiesDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StopEventsDetectionJobResponseTypeDef = TypedDict(
-    "StopEventsDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StopEventsDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StopKeyPhrasesDetectionJobResponseTypeDef = TypedDict(
-    "StopKeyPhrasesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StopKeyPhrasesDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 StopPiiEntitiesDetectionJobResponseTypeDef = TypedDict(
     "StopPiiEntitiesDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
+    {"JobId": str, "JobStatus": JobStatus},
     total=False,
 )
 
 StopSentimentDetectionJobResponseTypeDef = TypedDict(
-    "StopSentimentDetectionJobResponseTypeDef",
-    {
-        "JobId": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
-    },
-    total=False,
+    "StopSentimentDetectionJobResponseTypeDef", {"JobId": str, "JobStatus": JobStatus}, total=False
 )
 
 TopicsDetectionJobFilterTypeDef = TypedDict(
     "TopicsDetectionJobFilterTypeDef",
     {
         "JobName": str,
-        "JobStatus": Literal[
-            "SUBMITTED", "IN_PROGRESS", "COMPLETED", "FAILED", "STOP_REQUESTED", "STOPPED"
-        ],
+        "JobStatus": JobStatus,
         "SubmitTimeBefore": datetime,
         "SubmitTimeAfter": datetime,
     },
